@@ -150,7 +150,7 @@ if ($do==1) {
       ($stdout,$stderr)=$handle->cwd($appcmd);
       ($stdout,$stderr)=$handle->cmd("pwd",'__display__');
       my $sleep=0;
-      while (!(-e ./appcmd.exe)) {
+      while (!(-e "./appcmd.exe")) {
          sleep 2;
          last if $sleep++>300;
       }
@@ -187,6 +187,7 @@ if ($do==1) {
 cd bin
 /bin/perl -wT \\x241
 END
+      ($stdout,$stderr)=$handle->cwd("~/FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script");
       ($stdout,$stderr)=$handle->cwd("~");
       #($stdout,$stderr)=$handle->cmd("iisreset /start",'__display__');
@@ -1026,6 +1027,18 @@ END
            '__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING FCGI
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan FCGI",
+           '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING Catalyst::Helper::Model::DBIC::Schema
@@ -1452,7 +1465,7 @@ sub base : Chained('/base') PathPrefix CaptureArgs(0) {}
 sub admin : Chained('base') PathPart('') CaptureArgs(0) Does('ACL') RequiresRole('admin') ACLDetachTo('denied') {}
 
 sub change_password : Chained('base') PathPart('change_password') Args(0) {
-    my (\\x24self, \\x24c) = @_;
+    my (\\x24self, \\x24c) = \@_;
 
     my \\x24form = FullAutoAPI::Form::ChangePassword->new;
 
@@ -1474,7 +1487,7 @@ sub change_password : Chained('base') PathPart('change_password') Args(0) {
 }
 
 sub profile : Chained('base') PathPart('profile') Args(0) {
-    my (\\x24self, \\x24c) = @_;
+    my (\\x24self, \\x24c) = \@_;
 
     my \\x24form = MyApp::Form::UserProfile->new;
 
@@ -1670,6 +1683,7 @@ END
        '        }));%NL%'.
        '        $c->detach;%NL%'.
        '    }%NL%';
+       '}%NL%';
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/index : Private/i$ad\' ./Root.pm");
    ($stdout,$stderr)=$handle->cmd(
